@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0800';
+our $VERSION = '0.0801';
 
 use Algorithm::Combinatorics qw( combinations );
 use Math::Factor::XS qw( prime_factors );
@@ -281,7 +281,7 @@ Music::Intervals - Breakdown of musical intervals
 
 =head1 VERSION
 
-version 0.0800
+version 0.0801
 
 =head1 SYNOPSIS
 
@@ -316,7 +316,8 @@ version 0.0800
 =head1 DESCRIPTION
 
 A C<Music::Intervals> object shows the breakdown of musical notes,
-intervals and chords.
+intervals and chords.  (See L<Music::Intervals::Numeric> to use
+integer ratios instead of named notes.)
 
 This module reveals the "guts" within a given tonality.  And by guts I
 mean, the measurements of the notes and the intervals between them.
@@ -439,6 +440,22 @@ L<http://en.wikipedia.org/wiki/Just_intonation>
 
 L<Music::Scala> - A powerful module encompassing thousands of scales and the ratios therein
 
+=head2 DEPENDENCIES
+
+L<Algorithm::Combinatorics>
+
+L<Math::Factor::XS>
+
+L<MIDI::Pitch>
+
+L<Moo>
+
+L<Music::Intervals::Ratios>
+
+L<Music::Scales>
+
+L<Number::Fraction>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
